# coding: utf-8
import datetime
from sqlalchemy import BigInteger, Column, DateTime, Integer, Numeric, SmallInteger, String, Table, Text, text
from sqlalchemy.dialects.mysql import TINYINT, TIMESTAMP, DECIMAL
from sqlalchemy.ext.declarative import declarative_base


Base = declarative_base()
metadata = Base.metadata


class MAC_INDUSTRY_CATEGORY_GROWTH(Base):
    """
    全国行业分类增长速度
    """

    __tablename__ = "MAC_INDUSTRY_CATEGORY_GROWTH"

    id = Column(Integer, primary_key=True)
    stat_month = Column(String(20), nullable=False)
    coal_mining_yoy = Column(DECIMAL(10, 4))
    oil_gas_mining_yoy = Column(DECIMAL(10, 4))
    black_metal_mining_yoy = Column(DECIMAL(10, 4))
    nonferrous_metal_mining_yoy = Column(DECIMAL(10, 4))
    nonmetal_mining_yoy = Column(DECIMAL(10, 4))
    mining_aid_yoy = Column(DECIMAL(10, 4))
    other_mining_yoy = Column(DECIMAL(10, 4))
    agro_food_yoy = Column(DECIMAL(10, 4))
    food_manu_yoy = Column(DECIMAL(10, 4))
    drink_manu_yoy = Column(DECIMAL(10, 4))
    tobacco_manu_yoy = Column(DECIMAL(10, 4))
    textile_yoy = Column(DECIMAL(10, 4))
    cloth_manu_yoy = Column(DECIMAL(10, 4))
    leather_manu_yoy = Column(DECIMAL(10, 4))
    wood_manu_yoy = Column(DECIMAL(10, 4))
    furniture_manu_yoy = Column(DECIMAL(10, 4))
    paper_manu_yoy = Column(DECIMAL(10, 4))
    print_yoy = Column(DECIMAL(10, 4))
    refinery_yoy = Column(DECIMAL(10, 4))
    chemical_manu_yoy = Column(DECIMAL(10, 4))
    medical_manu_yoy = Column(DECIMAL(10, 4))
    chemical_fiber_yoy = Column(DECIMAL(10, 4))
    rubber_manu_yoy = Column(DECIMAL(10, 4))
    nonmetal_manu_yoy = Column(DECIMAL(10, 4))
    black_metal_manu_yoy = Column(DECIMAL(10, 4))
    nonferrous_metal_manu_yoy = Column(DECIMAL(10, 4))
    metal_product_manu_yoy = Column(DECIMAL(10, 4))
    general_equipment_manu_yoy = Column(DECIMAL(10, 4))
    professional_equipment_manu_yoy = Column(DECIMAL(10, 4))
    car_manu_yoy = Column(DECIMAL(10, 4))
    transport_manu_yoy = Column(DECIMAL(10, 4))
    electrical_equipment_manu_yoy = Column(DECIMAL(10, 4))
    communication_equipment_manu_yoy = Column(DECIMAL(10, 4))
    meter_manu_yoy = Column(DECIMAL(10, 4))
    other_manu_yoy = Column(DECIMAL(10, 4))
    reuse_manu_yoy = Column(DECIMAL(10, 4))
    repair_manu_yoy = Column(DECIMAL(10, 4))
    power_yoy = Column(DECIMAL(10, 4))
    gas_yoy = Column(DECIMAL(10, 4))
    water_yoy = Column(DECIMAL(10, 4))
    coal_mining_acc = Column(DECIMAL(10, 4))
    oil_gas_mining_acc = Column(DECIMAL(10, 4))
    black_metal_mining_acc = Column(DECIMAL(10, 4))
    nonferrous_metal_mining_acc = Column(DECIMAL(10, 4))
    nonmetal_mining_acc = Column(DECIMAL(10, 4))
    mining_aid_acc = Column(DECIMAL(10, 4))
    other_mining_acc = Column(DECIMAL(10, 4))
    agro_food_acc = Column(DECIMAL(10, 4))
    food_manu_acc = Column(DECIMAL(10, 4))
    drink_manu_acc = Column(DECIMAL(10, 4))
    tobacco_manu_acc = Column(DECIMAL(10, 4))
    textile_acc = Column(DECIMAL(10, 4))
    cloth_manu_acc = Column(DECIMAL(10, 4))
    leather_manu_acc = Column(DECIMAL(10, 4))
    wood_manu_acc = Column(DECIMAL(10, 4))
    furniture_manu_acc = Column(DECIMAL(10, 4))
    paper_manu_acc = Column(DECIMAL(10, 4))
    print_acc = Column(DECIMAL(10, 4))
    refinery_acc = Column(DECIMAL(10, 4))
    chemical_manu_acc = Column(DECIMAL(10, 4))
    medical_manu_acc = Column(DECIMAL(10, 4))
    chemical_fiber_acc = Column(DECIMAL(10, 4))
    rubber_manu_acc = Column(DECIMAL(10, 4))
    nonmetal_manu_acc = Column(DECIMAL(10, 4))
    black_metal_manu_acc = Column(DECIMAL(10, 4))
    nonferrous_metal_manu_acc = Column(DECIMAL(10, 4))
    metal_product_manu_acc = Column(DECIMAL(10, 4))
    general_equipment_manu_acc = Column(DECIMAL(10, 4))
    professional_equipment_manu_acc = Column(DECIMAL(10, 4))
    car_manu_acc = Column(DECIMAL(10, 4))
    transport_manu_acc = Column(DECIMAL(10, 4))
    electrical_equipment_manu_acc = Column(DECIMAL(10, 4))
    communication_equipment_manu_acc = Column(DECIMAL(10, 4))
    meter_manu_acc = Column(DECIMAL(10, 4))
    other_manu_acc = Column(DECIMAL(10, 4))
    reuse_manu_acc = Column(DECIMAL(10, 4))
    repair_manu_acc = Column(DECIMAL(10, 4))
    power_acc = Column(DECIMAL(10, 4))
    gas_acc = Column(DECIMAL(10, 4))
    water_acc = Column(DECIMAL(10, 4))
    status = Column(TINYINT(display_width=4), default=0)
    addTime = Column(TIMESTAMP, default=datetime.datetime.now)
    modTime = Column(TIMESTAMP)