# coding: utf-8
import datetime
from sqlalchemy import BigInteger, Column, DateTime, Integer, Numeric, SmallInteger, String, Table, Text, text
from sqlalchemy.dialects.mysql import TINYINT, TIMESTAMP, DECIMAL
from sqlalchemy.ext.declarative import declarative_base


Base = declarative_base()
metadata = Base.metadata


class MAC_AREA_GDP_EXPEND_YEAR(Base):
    """
    分地区支出法国内生产总值表(年度)
    """

    __tablename__ = "MAC_AREA_GDP_EXPEND_YEAR"

    id = Column(Integer, primary_key=True)
    stat_year = Column(String(4), nullable=False)
    area_code = Column(String(20), nullable=False)
    area_name = Column(String(100), nullable=False)
    gdp_expend = Column(DECIMAL(20, 4))
    gdp_fin_comsum_expend = Column(DECIMAL(20, 4))
    gdp_household_expend = Column(DECIMAL(20, 4))
    gdp_ruarl_household_expend = Column(DECIMAL(20, 4))
    gdp_citizen_household_expend = Column(DECIMAL(20, 4))
    gdp_gov_expend = Column(DECIMAL(20, 4))
    gdp_gross_capital_format = Column(DECIMAL(20, 4))
    gdp_gross_fixed_format = Column(DECIMAL(20, 4))
    gdp_gross_inventory_format = Column(DECIMAL(20, 4))
    gdp_net_export = Column(DECIMAL(20, 4))
    final_consum_rate = Column(DECIMAL(10, 4))
    capital_format_rate = Column(DECIMAL(10, 4))
    status = Column(TINYINT(display_width=4), default=0)
    addTime = Column(TIMESTAMP, default=datetime.datetime.now)
    modTime = Column(TIMESTAMP)